<?php

/**
 * Description of AssertionPolicy
 *
 * @author Luis Javier Gomez Santana <luis.gomez at rediris.es>
 */
class AssertionPolicy {

    private $attrs;

    /**
     *
     * @param String $xmlElem 
     */
    public function __construct($xmlElem = "") {
        $this->conditionAttrs = "none";
        $this->attrs = array();
        if (!is_string($xmlElem)) {
            $this->loadFromXML($xmlElem);
        }
    }

    /**
     *
     * @param String $xmlElem      
     */
    private function loadFromXML($xmlElem) {
        if (count($xmlElem->Attributes) > 0) {
            foreach ($xmlElem->Attributes as $attr) {
                $cond = (string) $attr['check'];
                $a = array('cond' => $cond);
                foreach ($attr->children() as $attrXML) {
                    $a['attr'][(string) $attrXML["name"]][] = (string) $attrXML["value"];
                }
                $this->attrs[] = $a;
            }
        }
    }

    /**
     *
     * @return Array 
     */
    private function getAttributes() {
        return $this->attrs;
    }

    /**
     *
     * @param Array $assertionAttrs The asssertion received
     * @return boolean True if the assertion complies with policy
     */
    public function checkPolicy($assertionAttrs) {
        $res = true;
        foreach ($this->getAttributes() as $polAttrs) {
            $condition = $polAttrs['cond'];
            $resPar = $this->checkPolicyConditional($condition, $assertionAttrs, $polAttrs['attr']);
            $res = $res && $resPar;
            if (!$res)
                break;
        }
        return $res;
    }

    /**
     *
     * @param String $cond The value of the check field from Attributes tag
     * @param Array $assertionAttrs The assertion received
     * @param Array $polAttrs The array of attributes loaded from the policy
     * @return boolean 
     */
    public function checkPolicyConditional($cond, $assertionAttrs, $polAttrs) {
        if (strcmp($cond, 'any') == 0)
            $res = $this->checkPolicyAny($assertionAttrs, $polAttrs);
        elseif (strcmp($cond, 'none') == 0)
            $res = $this->checkPolicyNone($assertionAttrs, $polAttrs);
        elseif (strcmp($cond, 'all') == 0)
            $res = $this->checkPolicyAll($assertionAttrs, $polAttrs);
        return $res;
    }

    /**
     *
     * @param type $assertionAttrs
     * @param type $polAttrs
     * @return boolean 
     */
    public function checkPolicyAny($assertionAttrs, $polAttrs) {
        $res = false;
        foreach ($polAttrs as $attrName => $arrayValues) {
            if (in_array($attrName, array_keys($assertionAttrs))) {
                $attAssValue = $assertionAttrs[$attrName];
                foreach ($arrayValues as $value) {
                    if (strcmp($value, $attAssValue) == 0)
                        $res = true;
                }
            }else
                $res = false;
        }
        return $res;
    }

    /**
     *
     * @param type $assertionAttrs
     * @param type $polAttrs
     * @return boolean 
     */
    public function checkPolicyNone($assertionAttrs, $polAttrs) {
        foreach ($polAttrs as $attrName => $arrayValues) {
            if (in_array($attrName, array_keys($assertionAttrs))) {
                $attAssValue = $assertionAttrs[$attrName];
                foreach ($arrayValues as $value) {
                    if (strcmp($value, $attAssValue) == 0)
                        $res = false;
                    else
                        $res = true;
                }
            }else
                $res = false;
        }
        return $res;
    }

    /**
     * No puede haber un campo repetido con distintos valores del mismo atributo
     * tipo(no tendría sentido):
     * <Attributes check="all">
     *   <Attribute name="sHO" value="rediris.es"/>
     *   <Attribute name="sHO" value="us.es"/>
     * </Attributes>
     * @param type $assertionAttrs
     * @param type $polAttrs
     * @return boolean 
     */
    public function checkPolicyAll($assertionAttrs, $polAttrs) {
        $matched = 0;
        foreach ($polAttrs as $attrName => $arrayValues) {
            if (in_array($attrName, array_keys($assertionAttrs))) {
                $attAssValue = $assertionAttrs[$attrName];
                if (strcmp($arrayValues[0], $attAssValue) == 0)
                    $matched++;
                else
                    $res = false;
            }else
                $res = false;
        }
        if ($matched == count($polAttrs))
            $res = true;

        return $res;
    }

}

?>
