<?php

/**
 * Description of LoadResourceConfig
 *
 * @author Luis Javier Gomez Santana <luis.gomez at rediris.es>
 */
class LoadResourceConfig {

    protected $classes;
    protected $archive_names;
    protected $token_formats;

    /**
     *
     * @param String $dir 
     */
    public function __construct($dir="") {
        $this->classes = array();
        $this->archive_names = array();
        $this->token_formats = array();
        if ($dir == '') {
            $file = dirname(dirname(__FILE__)) . "/config/resourceClasses.xml";
        } else {
            $file = $dir . "resourceClasses.xml";
        }
        $this->loadFile($file);
    }
    
    /**
     *
     * @param String $file 
     */
    public function loadFile($file) {
        $xml = simplexml_load_file($file);
        try{
            foreach ($xml as $child) {
                $id = (String) $child['id'];
                if(isset($child->ResourceClass))
                    $this->classes[$id] = (String) $child->ResourceClass;
                if(isset($child->ResourceFile))
                    $this->archive_names[$id] = (String) $child->ResourceFile;
                if(isset($child->TokenFormat)){
                    foreach($child->TokenFormat->children() as $ch){
                        $this->token_formats[$id][] = trim((string)$ch,"%");
                    }
		}
            }
        }catch (Exception $exc) {
            header("HTTP/1.0 400 Bad Request");
            header("Content-Type: application/json");
            header("Cache-control:no-store");
            echo json_encode(array("error" => $exc->getMessage()));
        }
    }
    
    /**
     *
     * @param String $scope
     * @return String 
     */
    public function getClass($scope) {
        return $this->classes[$scope];
    }

    /**
     *
     * @param String $scope
     * @return String 
     */
    public function getArchiveName($scope) {
        return $this->archive_names[$scope];
    }
    
    /**
     *
     * @param String $scope
     * @return String 
     */
    public function hasClass($scope) {
        return array_key_exists($scope,$this->classes);
    }

    /**
     *
     * @param String $scope
     * @return String 
     */
    public function hasArchiveName($scope) {
        return array_key_exists($scope, $this->archive_names);
    }
    
    /**
     *
     * @param String $scope
     * @return String 
     */
    public function getTokenFormats($scope){
        return $this->token_formats[$scope];
    }
    
    /**
     *
     * @param String $scope
     * @return String 
     */
    public function hasTokenFormats($scope) {
        return array_key_exists($scope, $this->token_formats);
    }

}

?>
